# List of TODO Items


* Add standards based grading / tagging
* Add module to help with external languages (c/cpp)
* Move neugs-build script to be _config.yaml file based
  * create ignore option by leading with _ to distinguish tests to actually upload
  * setup neugs-build to build both TierMastery files and standard JSONRunner run_tests.py (toggle flag in config)
  * make sure there are options for the setup.sh in the config based on needed apt-get installs